..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Performance of Python Data Structures
-------------------------------------

Now that you have a general idea of Big O notation
and the differences between the different functions, our goal in this
section is to tell you about the Big O performance for the operations on
Python lists and dictionaries. We will then show you some timing
experiments that illustrate the costs and benefits of using certain
operations on each data structure. It is important for you to understand
the efficiency of these Python data structures because they are the
building blocks we will use as we implement other data structures in the
remainder of the book. In this section we are not going to explain why
the performance is what it is. In later chapters you will see some
possible implementations of both lists and dictionaries and how the
performance depends on the implementation.
